@@ -28,6 +28,9 @@
 #include <gdk/gdkkeysyms.h>
 #include "gtkhtml-color-swatch.h"
 
+/* backward-compatibility cruft */
+#include "gtkhtml/gtk-compat.h"
+
 #define NUM_CUSTOM_COLORS	8
 
 #define GTKHTML_COLOR_COMBO_GET_PRIVATE(obj) \
@@ -152,6 +155,7 @@ color_combo_reposition_window (GtkhtmlColorCombo *combo)
 	GdkScreen *screen;
 	GdkWindow *window;
 	GdkRectangle monitor;
+	GtkAllocation allocation;
 	gint monitor_num;
 	gint x, y, width, height;
 
@@ -163,12 +167,14 @@ color_combo_reposition_window (GtkhtmlColorCombo *combo)
 	gdk_window_get_origin (window, &x, &y);
 
 	if (!gtk_widget_get_has_window (GTK_WIDGET (combo))) {
-		x += GTK_WIDGET (combo)->allocation.x;
-		y += GTK_WIDGET (combo)->allocation.y;
+		gtk_widget_get_allocation (GTK_WIDGET (combo), &allocation);
+		x += allocation.x;
+		y += allocation.y;
 	}
 
-	width = combo->priv->window->allocation.width;
-	height = combo->priv->window->allocation.height;
+	gtk_widget_get_allocation (combo->priv->window, &allocation);
+	width = allocation.width;
+	height = allocation.height;
 
 	x = CLAMP (x, monitor.x, monitor.x + monitor.width - width);
 	y = CLAMP (y, monitor.y, monitor.y + monitor.height - height);
@@ -615,7 +621,7 @@ color_combo_size_allocate (GtkWidget *widget,
 
 	priv = GTKHTML_COLOR_COMBO_GET_PRIVATE (widget);
 
-	widget->allocation = *allocation;
+	gtk_widget_set_allocation (widget, allocation);
 	gtk_widget_size_allocate (priv->toggle_button, allocation);
 }
 
@@ -628,11 +634,7 @@ color_combo_popup (GtkhtmlColorCombo *combo)
 	GdkGrabStatus status;
 	const gchar *label;
 
-#if GTK_CHECK_VERSION(2,19,7)
 	if (!gtk_widget_get_realized (GTK_WIDGET (combo)))
-#else
-	if (!GTK_WIDGET_REALIZED (combo))
-#endif
 		return;
 
 	if (combo->priv->popup_shown)
@@ -679,11 +681,7 @@ color_combo_popdown (GtkhtmlColorCombo *combo)
 {
 	GtkToggleButton *toggle_button;
 
-#if GTK_CHECK_VERSION(2,19,7)
 	if (!gtk_widget_get_realized (GTK_WIDGET (combo)))
-#else
-	if (!GTK_WIDGET_REALIZED (combo))
-#endif
 		return;
 
 	if (!combo->priv->popup_shown)
@@ -724,8 +722,8 @@ color_combo_class_init (GtkhtmlColorComboClass *class)
 		PROP_CURRENT_COLOR,
 		g_param_spec_boxed (
 			"current-color",
-			_("Current color"),
-			_("The currently selected color"),
+			"Current color",
+			"The currently selected color",
 			GDK_TYPE_COLOR,
 			G_PARAM_READWRITE));
 
@@ -734,8 +732,8 @@ color_combo_class_init (GtkhtmlColorComboClass *class)
 		PROP_DEFAULT_COLOR,
 		g_param_spec_boxed (
 			"default-color",
-			_("Default color"),
-			_("The color associated with the default button"),
+			"Default color",
+			"The color associated with the default button",
 			GDK_TYPE_COLOR,
 			G_PARAM_CONSTRUCT |
 			G_PARAM_READWRITE));
@@ -745,8 +743,8 @@ color_combo_class_init (GtkhtmlColorComboClass *class)
 		PROP_DEFAULT_LABEL,
 		g_param_spec_string (
 			"default-label",
-			_("Default label"),
-			_("The label for the default button"),
+			"Default label",
+			"The label for the default button",
 			_("Default"),
 			G_PARAM_CONSTRUCT |
 			G_PARAM_READWRITE));
@@ -756,8 +754,8 @@ color_combo_class_init (GtkhtmlColorComboClass *class)
 		PROP_DEFAULT_TRANSPARENT,
 		g_param_spec_boolean (
 			"default-transparent",
-			_("Default is transparent"),
-			_("Whether the default color is transparent"),
+			"Default is transparent",
+			"Whether the default color is transparent",
 			FALSE,
 			G_PARAM_CONSTRUCT |
 			G_PARAM_READWRITE));
@@ -767,8 +765,8 @@ color_combo_class_init (GtkhtmlColorComboClass *class)
 		PROP_PALETTE,
 		g_param_spec_object (
 			"palette",
-			_("Color palette"),
-			_("Custom color palette"),
+			"Color palette",
+			"Custom color palette",
 			GTKHTML_TYPE_COLOR_PALETTE,
 			G_PARAM_READWRITE));
 
@@ -777,14 +775,8 @@ color_combo_class_init (GtkhtmlColorComboClass *class)
 		PROP_POPUP_SHOWN,
 		g_param_spec_boolean (
 			"popup-shown",
-			/* Translators: This is the nickname for a
-			 * GtkhtmlColorCombo property named "popup-shown",
-			 * based on a similar property in GtkComboBox. */
-			_("Popup shown"),
-			/* Translators: This is the blurb for a
-			 * GtkhtmlColorCombo property named "popup-shown",
-			 * based on a similar property in GtkComboBox. */
-			_("Whether the combo's dropdown is shown"),
+			"Popup shown",
+			"Whether the combo's dropdown is shown",
 			FALSE,
 			G_PARAM_READWRITE));
 
@@ -793,16 +785,8 @@ color_combo_class_init (GtkhtmlColorComboClass *class)
 		PROP_STATE,
 		g_param_spec_object (
 			"state",
-			/* Translators: This is the nickname for a
-			GtkHtmlColorCombo property named "state". It holds all
-			the internal values for a GtkHtml color combination box.
-			*/
-			_("Color state"),
-			/* Translators: This is the blurb for a
-			GtkHtmlColorCombo property named "state". It holds all
-			the internal values for a GtkHtml color combination box.
-			*/
-			_("The state of a color combo box"),
+			"Color state",
+			"The state of a color combo box",
 			GTKHTML_TYPE_COLOR_STATE,
 			G_PARAM_READWRITE));
 
@@ -834,20 +818,20 @@ color_combo_class_init (GtkhtmlColorComboClass *class)
 
 	gtk_binding_entry_add_signal (
 		gtk_binding_set_by_class (class),
-		GDK_Down, GDK_MOD1_MASK, "popup", 0);
+		GDK_KEY_Down, GDK_MOD1_MASK, "popup", 0);
 	gtk_binding_entry_add_signal (
 		gtk_binding_set_by_class (class),
-		GDK_KP_Down, GDK_MOD1_MASK, "popup", 0);
+		GDK_KEY_KP_Down, GDK_MOD1_MASK, "popup", 0);
 
 	gtk_binding_entry_add_signal (
 		gtk_binding_set_by_class (class),
-		GDK_Up, GDK_MOD1_MASK, "popdown", 0);
+		GDK_KEY_Up, GDK_MOD1_MASK, "popdown", 0);
 	gtk_binding_entry_add_signal (
 		gtk_binding_set_by_class (class),
-		GDK_KP_Up, GDK_MOD1_MASK, "popdown", 0);
+		GDK_KEY_KP_Up, GDK_MOD1_MASK, "popdown", 0);
 	gtk_binding_entry_add_signal (
 		gtk_binding_set_by_class (class),
-		GDK_Escape, 0, "popdown", 0);
+		GDK_KEY_Escape, 0, "popdown", 0);
 }
 
 static void
