@@ -30,6 +30,9 @@
 
 #include "gtkhtml-face-chooser.h"
 
+/* backward-compatibility cruft */
+#include "gtkhtml/gtk-compat.h"
+
 #define GTKHTML_FACE_TOOL_BUTTON_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
 	((obj), GTKHTML_TYPE_FACE_TOOL_BUTTON, GtkhtmlFaceToolButtonPrivate))
@@ -109,6 +112,7 @@ face_tool_button_reposition_window (GtkhtmlFaceToolButton *button)
 	GdkScreen *screen;
 	GdkWindow *window;
 	GdkRectangle monitor;
+	GtkAllocation allocation;
 	gint monitor_num;
 	gint x, y, width, height;
 
@@ -120,12 +124,14 @@ face_tool_button_reposition_window (GtkhtmlFaceToolButton *button)
 	gdk_window_get_origin (window, &x, &y);
 
 	if (!gtk_widget_get_has_window (GTK_WIDGET (button))) {
-		x += GTK_WIDGET (button)->allocation.x;
-		y += GTK_WIDGET (button)->allocation.y;
+		gtk_widget_get_allocation (GTK_WIDGET (button), &allocation);
+		x += allocation.x;
+		y += allocation.y;
 	}
 
-	width = button->priv->window->allocation.width;
-	height = button->priv->window->allocation.height;
+	gtk_widget_get_allocation (button->priv->window, &allocation);
+	width = allocation.width;
+	height = allocation.height;
 
 	x = CLAMP (x, monitor.x, monitor.x + monitor.width - width);
 	y = CLAMP (y, monitor.y, monitor.y + monitor.height - height);
@@ -328,11 +334,7 @@ face_tool_button_popup (GtkhtmlFaceToolButton *button)
 	GdkWindow *window;
 	GdkGrabStatus status;
 
-#if GTK_CHECK_VERSION(2,19,7)
 	if (!gtk_widget_get_realized (GTK_WIDGET (button)))
-#else
-	if (!GTK_WIDGET_REALIZED (button))
-#endif
 		return;
 
 	if (button->priv->popup_shown)
@@ -374,11 +376,7 @@ face_tool_button_popdown (GtkhtmlFaceToolButton *button)
 {
 	GtkToggleToolButton *tool_button;
 
-#if GTK_CHECK_VERSION(2,19,7)
 	if (!gtk_widget_get_realized (GTK_WIDGET (button)))
-#else
-	if (!GTK_WIDGET_REALIZED (button))
-#endif
 		return;
 
 	if (!button->priv->popup_shown)
@@ -491,20 +489,20 @@ face_tool_button_class_init (GtkhtmlFaceToolButtonClass *class)
 
 	gtk_binding_entry_add_signal (
 		gtk_binding_set_by_class (class),
-		GDK_Down, GDK_MOD1_MASK, "popup", 0);
+		GDK_KEY_Down, GDK_MOD1_MASK, "popup", 0);
 	gtk_binding_entry_add_signal (
 		gtk_binding_set_by_class (class),
-		GDK_KP_Down, GDK_MOD1_MASK, "popup", 0);
+		GDK_KEY_KP_Down, GDK_MOD1_MASK, "popup", 0);
 
 	gtk_binding_entry_add_signal (
 		gtk_binding_set_by_class (class),
-		GDK_Up, GDK_MOD1_MASK, "popdown", 0);
+		GDK_KEY_Up, GDK_MOD1_MASK, "popdown", 0);
 	gtk_binding_entry_add_signal (
 		gtk_binding_set_by_class (class),
-		GDK_KP_Up, GDK_MOD1_MASK, "popdown", 0);
+		GDK_KEY_KP_Up, GDK_MOD1_MASK, "popdown", 0);
 	gtk_binding_entry_add_signal (
 		gtk_binding_set_by_class (class),
-		GDK_Escape, 0, "popdown", 0);
+		GDK_KEY_Escape, 0, "popdown", 0);
 }
 
 static void
