@@ -63,7 +63,7 @@ struct _HTMLImageFactory {
 static HTMLImageClass html_image_class;
 static HTMLObjectClass *parent_class = NULL;
 
-static HTMLImagePointer   *html_image_pointer_new               (const char *filename, HTMLImageFactory *factory);
+static HTMLImagePointer   *html_image_pointer_new               (const gchar *filename, HTMLImageFactory *factory);
 static void                html_image_pointer_ref               (HTMLImagePointer *ip);
 static void                html_image_pointer_unref             (HTMLImagePointer *ip);
 static gboolean            html_image_pointer_timeout           (HTMLImagePointer *ip);
@@ -92,7 +92,7 @@ html_image_get_actual_width (HTMLImage *image, HTMLPainter *painter)
 		width = gdk_pixbuf_animation_get_width (anim) * pixel_size;
 
 		if (image->specified_height > 0 || image->percent_height) {
-			double scale;
+			gdouble scale;
 
 			scale =  ((double) html_image_get_actual_height (image, painter))
 				/ (gdk_pixbuf_animation_get_height (anim) * pixel_size);
@@ -125,7 +125,7 @@ html_image_get_actual_height (HTMLImage *image, HTMLPainter *painter)
 		height = gdk_pixbuf_animation_get_height (anim) * pixel_size;
 
 		if (image->specified_width > 0 || image->percent_width) {
-			double scale;
+			gdouble scale;
 
 			scale = ((double) html_image_get_actual_width (image, painter))
 				/ (gdk_pixbuf_animation_get_width (anim) * pixel_size);
@@ -213,7 +213,7 @@ image_update_url (HTMLImage *image, gint x, gint y)
 {
 	HTMLMap *map;
 	HTMLObject *o = HTML_OBJECT (image);
-	char *url = NULL;
+	gchar *url = NULL;
 
 	/*
 	 * FIXME this is a huge hack waiting until we implement events for now we write
@@ -599,14 +599,14 @@ save (HTMLObject *self,
 	if (image->url && *image->url) {
 		url  = g_strconcat (image->url, image->target ? "#" : "", image->target, NULL);
 		link = TRUE;
-		result = html_engine_save_output_string (state, "<A HREF=\"%s\">", url);
+		result = html_engine_save_delims_and_vals (state, "<A HREF=\"", url, "\">", NULL);
 		g_free (url);
 		if (!result)
 			return FALSE;
 	}
 
 	url    = html_image_resolve_image_url (state->engine->widget, image->image_ptr->url);
-	result = html_engine_save_output_string (state, "<IMG SRC=\"%s\"", url);
+	result = html_engine_save_delims_and_vals (state, "<IMG SRC=\"", url, "\"", NULL);
 	g_free (url);
 	if (!result)
 		return FALSE;
@@ -648,7 +648,7 @@ save (HTMLObject *self,
 	}
 
 	if (image->alt) {
-		if (!html_engine_save_output_string (state, " ALT=\"%s\"", image->alt))
+		if (!html_engine_save_delims_and_vals (state, " ALT=\"", image->alt, "\"", NULL))
 			return FALSE;
 	}
 
@@ -873,7 +873,7 @@ html_image_new (HTMLImageFactory *imf,
 {
 	HTMLImage *image;
 
-	image = g_new(HTMLImage, 1);
+	image = g_new (HTMLImage, 1);
 
 	html_image_init (image, &html_image_class,
 			 imf,
@@ -965,7 +965,7 @@ html_image_set_alt (HTMLImage *image, const gchar *alt)
 void
 html_image_set_map (HTMLImage *image, gchar *usemap, gboolean ismap)
 {
-	char *url = NULL;
+	gchar *url = NULL;
 
 	g_free (image->usemap);
 
@@ -1009,13 +1009,13 @@ html_image_set_size (HTMLImage *image, gint w, gint h, gboolean pw, gboolean ph)
 	}
 }
 
-static char *fallback_image_content_types[] = {"image/*", NULL};
+static gchar *fallback_image_content_types[] = { (gchar *) "image/*", NULL};
 
-static char **
+static gchar **
 html_image_factory_types (GtkHTMLStream *stream,
 			  gpointer user_data)
 {
-	static char**image_content_types = NULL;
+	static gchar **image_content_types = NULL;
 
 #if 0
 	/* this code should work in gtk+-2.2 but it is untested */
@@ -1029,7 +1029,7 @@ html_image_factory_types (GtkHTMLStream *stream,
 
 		for (cur = formats; cur; cur = cur->next) {
 			GdkPixbufFormat *format = cur->data;
-			char **mime;
+			gchar **mime;
 
 			mime = gdk_pixbuf_formats_get_mime_types ();
 			for (i = 0; mime && mime[i]; i++)
@@ -1039,7 +1039,7 @@ html_image_factory_types (GtkHTMLStream *stream,
 		g_slist_free (formats);
 
 		if (types) {
-			image_content_types = g_new0 (char *, g_slist_length (types) + 1);
+			image_content_types = g_new0 (gchar *, g_slist_length (types) + 1);
 
 			for (cur = types, i = 0; cur; cur = cur->next, i++) {
 				image_content_types[i] = cur->data;
@@ -1057,7 +1057,8 @@ html_image_factory_types (GtkHTMLStream *stream,
 }
 
 static void
-update_or_redraw (HTMLImagePointer *ip){
+update_or_redraw (HTMLImagePointer *ip)
+{
 	GSList *list;
 	gboolean update = FALSE;
 
@@ -1141,12 +1142,12 @@ html_image_factory_end_pixbuf (GtkHTMLStream *stream,
 static void
 html_image_factory_write_pixbuf (GtkHTMLStream *stream,
 				 const gchar *buffer,
-				 size_t size,
+				 gsize size,
 				 gpointer user_data)
 {
 	HTMLImagePointer *p = user_data;
 
-	/* FIXME ! Check return value */
+	/* FIXME !Check return value */
 	gdk_pixbuf_loader_write (p->loader, (const guchar *) buffer, size, NULL);
 }
 
@@ -1262,7 +1263,7 @@ cleanup_images (gpointer key, gpointer value, gpointer free_everything)
 	HTMLImagePointer *ip = value;
 
 	/* free_everything means: NULL only clean, non-NULL free */
-	if (free_everything){
+	if (free_everything) {
 		if (ip->interests != NULL) {
 			g_slist_free (ip->interests);
 			ip->interests = NULL;
@@ -1270,7 +1271,7 @@ cleanup_images (gpointer key, gpointer value, gpointer free_everything)
 	}
 
 	/* clean only if this image is not used anymore */
-	if (!ip->interests){
+	if (!ip->interests) {
 		html_image_pointer_unref (ip);
 		ip->factory = NULL;
 		return TRUE;
@@ -1303,7 +1304,7 @@ html_image_factory_free (HTMLImageFactory *factory)
 #define STALL_INTERVAL 1000
 
 static HTMLImagePointer *
-html_image_pointer_new (const char *filename, HTMLImageFactory *factory)
+html_image_pointer_new (const gchar *filename, HTMLImageFactory *factory)
 {
 	HTMLImagePointer *retval;
 
@@ -1422,7 +1423,7 @@ html_image_pointer_load (HTMLImagePointer *ip)
 }
 
 HTMLImagePointer *
-html_image_factory_register (HTMLImageFactory *factory, HTMLImage *i, const char *url, gboolean reload)
+html_image_factory_register (HTMLImageFactory *factory, HTMLImage *i, const gchar *url, gboolean reload)
 {
 	HTMLImagePointer *ip;
 	GtkHTMLStream *stream = NULL;
@@ -1576,7 +1577,6 @@ deactivate_anim (gpointer key, gpointer value, gpointer user_data)
 	GSList *cur = ip->interests;
 	HTMLImage *image;
 
-
 	while (cur) {
 		if (cur->data) {
 			image = (HTMLImage *) cur->data;
